//Draw Allted's Simple CNC Table based on input dimensions using openscad
//Translated into openscad on 4/4/2016  by: David Bunch
//
//The default dimensions are what I am using for a table, 48"Long x 36"Wide x 30"High
//This is drawn in Inches, set ScaleFactor variable to 25.4 to draw in millimeters
//Rev2 - revised for Quantity of Top Ledge Lengths if only 1 middle stiffener used
//Rev3 - Legs, Top Ledges & Shelf Ledges can be different Widths & thickness now
//       I made this change because I want to use 2x3's for the Shelf ledges
//Rev4 - Display Shelf Usable Heights with a visual cube for each shelf
//Rev5 - Added Mid_Y_Offset variable for middle top ledges rather than hardcoded 6"
//       Offset is from each edge when using 2 middle top supports
//CUSTOMIZER VARIABLES
//If you want your MPCNC corners to be right at corners of table,
//Set Len & Wid the same as your CNC_LEN & CNC_Wid
Len = 48;                   //Length of Table
Wid = 36;                   //Width of Table
Ht = 30;                    //Height of Table at top of Ledges
LegWd24_Wid = 3.5;          //Width Legs (I am using 2x4)
LegWd24_Thk = 1.5;          //Thickness of 2Legs

TopLedgeWd24_Wid = 3.5;     //Width of Top Ledge Boards (2x4 is what I use)
TopLedgeWd24_Thk = 1.5;     //Thickness of Top Ledge Boards
Mid_Y_Offset = 12;        //Only used if 2 middle ledges are used
                            //This is offset from each side
MidTopLedgeQty = 2;         //How many middle stiffener ledges, 1 or 2

EdgeWd_Wid = 6;             //How wide of top to put along edges
EdgeWd_Thk = 1;             //How thick the top is

Shelf_Qty = 2;              //0,1 or 2
Shelf1_Ht = 5;              //Shelf height of lower shelf
Shelf2_Ht = 16;             //Shelf height of upper shelf
ShelfThk = 0.5;             //Thickness of Shelves
ShelfLedgeWd24_Wid = 2.5;   //Width of Shelf Ledge Boards (Default is 2x4)
ShelfLedgeWd24_Thk = 1.5;   //Thickness of Shelf Ledge Boards
                        //I am going to use 2x3 to give me a little extra shelf height
Shelf_Cube_X = 12;  //Visual Show Shelf Cube this size in X
Shelf_Cube_Y = 10.5;  //Visual Show Shelf Cube this size in Y
CNC_Len = 43;       //Length of Physical MPCNC (subtract 11 for work Length)
                    //Length is the Y-Axis on my machine
CNC_Wid = 33;       //Width of Physical MPCNC (subtract 11 for work Width)
                    //Width is the X-Axis on my machine
EMT_OD = 23.6 / 25.4;       //Diameter of EMT, convert to Inches
ScaleFactor = 1;    //1 = draw in Inches, set to 25.4 to draw in millimeters
//CUSTOMIZER VARIABLES END

//Calculate Usable Shelf Space Heights
ToeSpace = Shelf1_Ht - ShelfLedgeWd24_Wid;  //Space Below Bottom Shelf Ledge
OneShelfSpace = Ht - TopLedgeWd24_Wid - (Shelf1_Ht + ShelfThk);
BotShelfSpace = Shelf2_Ht - ShelfLedgeWd24_Wid - (Shelf1_Ht + ShelfThk);
TopShelfSpace = Ht - TopLedgeWd24_Wid - (Shelf2_Ht + ShelfThk);

//Your actual work area will probably be less depending on
//what size router you are using & how wide your tool holder is
CNC_WorkLen = CNC_Len - 11;         //Work area Length of MPCNC router
CNC_WorkWid = CNC_Wid - 11;         //Work area Width of MPCNC router
Work_Y_Loc = (Len - CNC_WorkLen)/2; //X & Y locations of work area in this drawing
Work_X_Loc = (Wid - CNC_WorkWid)/2;

TopMidWid = Wid-(EdgeWd_Wid*2);
CNC_Corner_Wid = 53.0 / 25.4;
CNC_Corner_Ht = 63.2 / 25.4;

Len2 = Len / 2;
Wid2 = Wid / 2;
CNC_Len2 = CNC_Len / 2;
CNC_Wid2 = CNC_Wid / 2;
CNC_Corner_Wid2 = CNC_Corner_Wid / 2;

WdTopLedgeLen = Len - (TopLedgeWd24_Thk * 2);
WdTopLedgeWid = Wid - (TopLedgeWd24_Thk * 2);

WdShelfLedgeLen = Len - (ShelfLedgeWd24_Thk * 2);
WdShelfLedgeWid = Wid - (ShelfLedgeWd24_Thk * 2);
ShelfWid = Wid - (LegWd24_Thk * 2);    //Width of each of the 1 or 2 shelf tops

MPCNC_X_Loc = Len2-CNC_Len2;    //MPCNC router X location from Lower Left corner
MPCNC_Y_Loc = Wid2-CNC_Wid2;    //MPCNC router Y location from Lower Left corner
PipeY_Z_Loc = 22.8 / 25.4;  //EMT Y Axis Z Height Location from base of Corner block
PipeX_Z_Loc = 50.4 / 25.4;  //EMT X Axis Z Height Location from base of Corner block

//Variables for Corner Side supports & Side Panels

Corn_Len = 24;          //Length of Corner Side Cover Supports
Corn_Wid = 3.5;         //Width of Corner (2x4)
Corn_Thk = 1.5;         //Thickness of Corner (2x4)
Corner_Cut = .5;        //How deep to cut corners to insert side panels
C_Thk2 = Corn_Thk / 2;
Panel_Thk = .25;        //Panel Thickness
P_Thk2 = Panel_Thk / 2;
echo(C_Thk2 = C_Thk2);
echo(C_Thk2+P_Thk2);
CP_Thk2 = C_Thk2 + P_Thk2;
//Corn_Z_Offset = Shelf2_Ht + ShelfThk;
Corn_Z_Offset = Ht-5;
echo(Corn_Z_Offset = Corn_Z_Offset);
Panel_Z_Offset = Corn_Z_Offset + Corn_Len - 24;
echo(Panel_Z_Offset = Panel_Z_Offset);

//Output Cut Data
if (ScaleFactor == 1)
{
    Header = "*******************************";
    Spacer = "----------------------------------------------";
    c = str("** Cut 4 Legs ",Ht,"\" Long");
    d1 = str("** Cut 3 Top Ledge Lengths ",WdTopLedgeLen,"\" Long");
    d2 = str("** Cut 4 Top Ledge Lengths ",WdTopLedgeLen,"\" Long");
    e = str("** Cut 2 Top Ledge Widths ",WdTopLedgeWid,"\" Long");
    FTS = str("** Cut 2 Top Edges ",Len,"\" x ",EdgeWd_Wid,"\" Wide");
    FTM = str("** Cut 1 Top Middle ",Len,"\" x ",TopMidWid,"\" Wide");
    FL1 = str("** Cut 2 Shelf Ledge Lengths ",WdTopLedgeLen,"\" Long");
    FW1 = str("** Cut 2 Shelf Ledge Widths ",WdTopLedgeWid,"\" Long");
    FS1 = str("** Cut 1 shelves ",Len,"\" x ",ShelfWid,"\" Wide");
    //ShelfWid
    FL2 = str("** Cut 4 Shelf Ledge Lengths ",WdTopLedgeLen,"\" Long");
    FW2 = str("** Cut 4 Shelf Ledge Widths ",WdTopLedgeWid,"\" Long");
    FS2 = str("** Cut 2 shelves ",Len,"\" x ",ShelfWid,"\" Wide");
    F_ToeSpace = str("** Toe Space Height = ",ToeSpace, chr(34));
    F_UseSpace = str("** Single Shelf Usable Height = ",OneShelfSpace, chr(34));
    F_UseSpace1 = str("** Bottom Shelf Usable Height = ",BotShelfSpace, "\"");
    F_UseSpace2 = str("** Top Shelf Usable Height = ",TopShelfSpace, "\"");   
    echo(Header);
    echo(c);
    if (MidTopLedgeQty == 1)
    {
        echo(d1);
    } else if (MidTopLedgeQty == 2)
    {
        echo(d2);
    }
    echo(e);
    echo(FTS);
    echo(FTM);
    echo(Spacer);
    if (Shelf_Qty == 1)
    {
        echo(FL1);
        echo(FW1);
        echo(FS1);
        echo(Spacer);
        echo(F_ToeSpace);
        echo(F_UseSpace);
//Draw Cube to Represent Toe Space"
        translate([0,LegWd24_Thk,0])
        %cube([Shelf_Cube_X,Shelf_Cube_Y,ToeSpace]);
//Draw Cube to Represent Bottom Shelf Height"
        color("red",.7)
        translate([0,0,Shelf1_Ht + ShelfThk])
        %cube([Shelf_Cube_X,Shelf_Cube_Y,OneShelfSpace]);

    } else if (Shelf_Qty == 2)
    {
        echo(FL2);
        echo(FW2);
        echo(FS2);
        echo(Spacer);
        echo(F_ToeSpace);
        echo(F_UseSpace1);
        echo(F_UseSpace2);
//Draw Cube to Represent Toe Space"
        translate([0,LegWd24_Thk,0])
        %cube([Shelf_Cube_X,Shelf_Cube_Y,ToeSpace]);
//Draw Cube to Represent Bottom Shelf Height"
        color("red",.7)
        translate([0,LegWd24_Thk,Shelf1_Ht + ShelfThk])
        %cube([Shelf_Cube_X,Shelf_Cube_Y,BotShelfSpace]);
//Draw Cube to Represent Top Shelf Height"
        color("blue",.7)
        translate([0,LegWd24_Thk,Shelf2_Ht + ShelfThk])
        %cube([Shelf_Cube_X,Shelf_Cube_Y,TopShelfSpace]);

    }
    echo(Header);
} else if (ScaleFactor == 25.4)
{
    Header = "**********************************";
    Spacer = "----------------------------------------------------";
    c = str("** Cut 4 Legs ",Ht*25.4,"mm Long");
    d = str("** Cut 4 Top Ledge Lengths ",WdTopLedgeLen*25.4,"mm Long");
    e = str("** Cut 2 Top Ledge Widths ",WdTopLedgeWid*25.4,"mm Long");
    FTS = str("** Cut 2 Top Edges ",Len*25.4,"\" x ",EdgeWd_Wid*25.4,"\" Wide");
    FTM = str("** Cut 1 Top Middle ",Len*25.4,"\" x ",TopMidWid*25.4,"\" Wide");
    FL1 = str("** Cut 2 Shelf Ledge Lengths ",WdTopLedgeLen*25.4,"mm Long");
    FW1 = str("** Cut 2 Shelf Ledge Widths ",WdTopLedgeWid*25.4,"mm Long");
    FS1 = str("** Cut 1 shelves ",Len*25.4,"\" x ",ShelfWid*25.4,"mm Wide");
    //ShelfWid
    FL2 = str("** Cut 4 Shelf Ledge Lengths ",WdTopLedgeLen*25.4,"mm Long");
    FW2 = str("** Cut 4 Shelf Ledge Widths ",WdTopLedgeWid*25.4,"mm Long");
    FS2 = str("** Cut 2 shelves ",Len*25.4,"\" x ",ShelfWid*25.4,"mm Wide");
    
    echo(Header);
    echo(c);
    echo(d);
    echo(e);
    echo(FTS);
    echo(FTM);
    echo(Spacer);
    if (Shelf_Qty == 1)
    {
        echo(FL1);
        echo(FW1);
        echo(FS1);
    } else if (Shelf_Qty == 2)
    {
        echo(FL2);
        echo(FW2);
        echo(FS2);
    }
    echo(Header);
}

module CornerFrame()
{
    color("orange")
    difference()
    {
        translate([0,-Corn_Thk,0])
        cube([Corn_Wid,Corn_Thk,Corn_Len]);
        translate([Corn_Wid-Corner_Cut,-CP_Thk2,-1])
        cube([6,Panel_Thk,38]);
    }
    difference()
    {
        translate([-Corn_Thk,-Corn_Thk,0])
        cube([Corn_Thk,Corn_Wid,Corn_Len]);
        translate([-CP_Thk2,Corn_Wid-Corn_Thk-Corner_Cut,-1])
        cube([Panel_Thk,6,38]);
    }
}
module Panel_Y()
{
    color("tan",.7)
    cube([Len - (Corn_Wid*2)+(Corner_Cut*2),Panel_Thk,24]);
}
module Panel_X()
{
    color("tan",.7)
    cube([Panel_Thk,Wid - (Corn_Wid)+(Corner_Cut*2),24]);
}
module Corners2()
{
    translate([0,0,Corn_Z_Offset])
    CornerFrame();
    translate([Len,0,Corn_Z_Offset])
    mirror([1,0,0])
    CornerFrame();
}

module Leg()
{
    cube([LegWd24_Wid,LegWd24_Thk,Ht]);
}
module TopEdge()
{
    color("tan",.7)
    cube([Len,EdgeWd_Wid,EdgeWd_Thk]);  
}
module TopMiddle()
{
    color("Peru",.7)
    cube([Len,Wid-(EdgeWd_Wid*2),EdgeWd_Thk]);
}
module Shelf()
{
    color("Peru",.7)
    cube([Len,ShelfWid,ShelfThk]);
}
module CornerBlk()
{
    translate([MPCNC_X_Loc,MPCNC_Y_Loc,Ht+EdgeWd_Thk])
    color("blue")
    {
        translate([0,0,0])
        cube([CNC_Corner_Wid,CNC_Corner_Wid,CNC_Corner_Ht]);
        translate([CNC_Len-CNC_Corner_Wid,0,0])
        cube([CNC_Corner_Wid,CNC_Corner_Wid,CNC_Corner_Ht]);
        translate([CNC_Len-CNC_Corner_Wid,CNC_Wid - CNC_Corner_Wid,0])
        cube([CNC_Corner_Wid,CNC_Corner_Wid,CNC_Corner_Ht]);
        translate([0,CNC_Wid - CNC_Corner_Wid,0])
        cube([CNC_Corner_Wid,CNC_Corner_Wid,CNC_Corner_Ht]);
    }
}
module EMT()
{
    translate([MPCNC_X_Loc,MPCNC_Y_Loc,Ht+EdgeWd_Thk])
    color("silver")
    {
//Y Pipes
        translate([0,CNC_Corner_Wid2,PipeY_Z_Loc])
        rotate([0,90,0])
        cylinder(d=EMT_OD,h=CNC_Len);
        translate([0,CNC_Wid-CNC_Corner_Wid2,PipeY_Z_Loc])
        rotate([0,90,0])
        cylinder(d=EMT_OD,h=CNC_Len);
//X Pipes
        translate([CNC_Corner_Wid2,0,PipeX_Z_Loc])
        rotate([-90,0,0])
        cylinder(d=EMT_OD,h=CNC_Wid);
        translate([CNC_Len-CNC_Corner_Wid2,0,PipeX_Z_Loc])
        rotate([-90,0,0])
        cylinder(d=EMT_OD,h=CNC_Wid);
    }
}
module TopLedges()
{
//Draw The Long Length Ledges (Len)
    color("cyan")
    {
        translate([TopLedgeWd24_Thk,LegWd24_Thk,0])
        cube([WdTopLedgeLen,TopLedgeWd24_Thk,TopLedgeWd24_Wid]);
        translate([TopLedgeWd24_Thk,Wid-LegWd24_Thk-TopLedgeWd24_Thk,0])
        cube([WdTopLedgeLen,TopLedgeWd24_Thk,TopLedgeWd24_Wid]);
    }
//Draw the Short Length Ledges (Wid)
    color("green")
    {
        translate([0,LegWd24_Thk,0])
        cube([TopLedgeWd24_Thk,Wid-(LegWd24_Thk*2),TopLedgeWd24_Wid]);
        translate([Len-TopLedgeWd24_Thk,LegWd24_Thk,0])
        cube([TopLedgeWd24_Thk,Wid-(LegWd24_Thk*2),TopLedgeWd24_Wid]);
    }
}
module ShelfLedges()
{
//Draw The Long Length Ledges (Len)
    color("cyan")
    {
        translate([ShelfLedgeWd24_Thk,LegWd24_Thk,0])
        cube([WdShelfLedgeLen,ShelfLedgeWd24_Thk,ShelfLedgeWd24_Wid]);
        translate([ShelfLedgeWd24_Thk,Wid-LegWd24_Thk-ShelfLedgeWd24_Thk,0])
        cube([WdShelfLedgeLen,ShelfLedgeWd24_Thk,ShelfLedgeWd24_Wid]);
    }
//Draw the Short Length Ledges (Wid)
    color("green")
    {
        translate([0,LegWd24_Thk,0])
        cube([ShelfLedgeWd24_Thk,Wid-(LegWd24_Thk*2),ShelfLedgeWd24_Wid]);
        translate([Len-ShelfLedgeWd24_Thk,LegWd24_Thk,0])
        cube([ShelfLedgeWd24_Thk,Wid-(LegWd24_Thk*2),ShelfLedgeWd24_Wid]);
    }
}
scale([ScaleFactor,ScaleFactor,ScaleFactor])
{
    CornerBlk();        //Draw 4 corner blocks
    EMT();              //Draw the EMT
    translate([Work_Y_Loc,Work_X_Loc,Ht+EdgeWd_Thk])
    color("red",.5)
    %cube([CNC_WorkLen,CNC_WorkWid,.25]);   //Draw Work Area
//
    translate([0,0,Ht])
    %TopEdge();         //Draw the 1st Top Edge
    translate([0,Wid-EdgeWd_Wid,Ht])
    %TopEdge();         //Draw the 2nd Top Edge
    translate([0,EdgeWd_Wid,Ht])
    %TopMiddle();       //Draw the Top Middle
    Leg();              //Draw 1st Leg
    translate([0,Wid-LegWd24_Thk,0])
    Leg();              //Draw 2nd Leg
    translate([Len-LegWd24_Wid,0,0])
    Leg();              //Draw 3rd Leg
    translate([Len-LegWd24_Wid,Wid-LegWd24_Thk,0])
    Leg();              //Draw 4th Leg
    translate([0,0,Ht-TopLedgeWd24_Wid])
    TopLedges();           //Draw the 4 top outside ledges that top rests on

 if (MidTopLedgeQty == 1)
    {
        translate([TopLedgeWd24_Thk,Wid/2-(LegWd24_Thk/2) ,Ht-TopLedgeWd24_Wid])
        cube([WdTopLedgeLen,TopLedgeWd24_Thk,TopLedgeWd24_Wid]);
    } else
    {
        translate([TopLedgeWd24_Thk,Mid_Y_Offset,Ht-TopLedgeWd24_Wid])
        cube([WdTopLedgeLen,TopLedgeWd24_Thk,TopLedgeWd24_Wid]);
        translate([TopLedgeWd24_Thk,Wid-Mid_Y_Offset,Ht-TopLedgeWd24_Wid])
        cube([WdTopLedgeLen,TopLedgeWd24_Thk,TopLedgeWd24_Wid]);
    }
    if (Shelf_Qty > 0)
    {
        translate([0,0,Shelf1_Ht-ShelfLedgeWd24_Wid])
        ShelfLedges();
        translate([0,LegWd24_Thk,Shelf1_Ht])
        Shelf();
    }
    if (Shelf_Qty > 1)
    {
        translate([0,0,Shelf2_Ht-ShelfLedgeWd24_Wid])
        ShelfLedges();
        translate([0,LegWd24_Thk,Shelf2_Ht])
        Shelf();
    }
}
//---------------------------------------------------------
//--------- Draw Side Panels with Corner Supports ---------
//---------------------------------------------------------
//
//Draw Corners along lower Y-axis
Corners2();
//Draw Corners along Upper Y-axis
translate([0,Wid,0])
mirror([0,1,0])
Corners2();
translate([0,0,0])  //Change Z offset to show how it fits in slot
{
    translate([Corn_Wid-Corner_Cut,-C_Thk2-P_Thk2,Panel_Z_Offset])
    %Panel_Y();
    translate([Corn_Wid-Corner_Cut,Wid+C_Thk2-P_Thk2,Panel_Z_Offset])
    %Panel_Y();
    translate([-C_Thk2-P_Thk2,Corn_Wid-Corn_Thk-Corner_Cut,Panel_Z_Offset])
    %Panel_X();
    translate([Len+C_Thk2-P_Thk2,Corn_Wid-Corn_Thk-Corner_Cut,Panel_Z_Offset])
    %Panel_X();
}
//Bottom 1x2 Y supports
translate([0,-1.5,Panel_Z_Offset-.75])
color("Maroon")
cube([Len,1.5,.75]);
translate([0,Wid,Panel_Z_Offset-.75])
color("Maroon")
cube([Len,1.5,.75]);
//Bottom X supports
translate([-1.5,-1.5,Panel_Z_Offset-.75])
color("Maroon")
cube([1.5,Wid+3,.75]);
translate([Len,-1.5,Panel_Z_Offset-.75])
color("Maroon")
cube([1.5,Wid+3,.75]);
//Uncomment to show the height above workbench that is covered
//color("SkyBlue",.7)
//translate([.5,.5,Ht])
//%cube([Len-1.5,Wid-1.5,19]);

//6" height for screwing Side Mount Corners to Legs along Y-axis
//color("Aqua",.7)
//translate([-1.5,-1.5,Shelf2_Ht + ShelfThk+7.75])
//%cube([5,3.5,6]);